@@ -5,9 +5,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-07-16'; # DATE
+our $DATE = '2022-09-11'; # DATE
 our $DIST = 'App-SahUtils'; # DIST
-our $VERSION = '0.480'; # VERSION
+our $VERSION = '0.481'; # VERSION
 
 our %SPEC;
 
@@ -348,7 +348,7 @@ App::SahUtils - Collection of CLI utilities for Sah and Data::Sah
 
 =head1 VERSION
 
-This document describes version 0.480 of App::SahUtils (from Perl distribution App-SahUtils), released on 2022-07-16.
+This document describes version 0.481 of App::SahUtils (from Perl distribution App-SahUtils), released on 2022-09-11.
 
 =head1 SYNOPSIS
 
@@ -837,9 +837,10 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
